@@ -30,16 +30,21 @@ def do_discover():
     for stream_name, schema in raw_schemas.items():
         # create and add catalog entry
         stream = STREAM_OBJECTS[stream_name]
+        mdata = metadata.get_standard_metadata(
+            schema=schema,
+            key_properties=stream.key_properties,
+            valid_replication_keys=stream.replication_keys,
+            replication_method=stream.replication_method,
+        )
+        mdata = metadata.to_map(mdata)
+        for field_name in stream.replication_keys:
+            metadata.write(mdata, ('properties', field_name), 'inclusion', 'automatic')
+
         catalog_entry = {
             "stream": stream_name,
             "tap_stream_id": stream_name,
             "schema": schema,
-            "metadata": metadata.get_standard_metadata(
-                schema=schema,
-                key_properties=stream.key_properties,
-                valid_replication_keys=stream.replication_keys,
-                replication_method=stream.replication_method,
-            ),
+            "metadata": metadata.to_list(mdata),
             "key_properties": stream.key_properties,
         }
         catalog_entries.append(catalog_entry)
